import os
import subprocess
from colorama import Fore, Back, Style
from . import env, git, message, cmake

name = "install-requirements"
help = """Install packages requirements"""
usage = ""
min_args = 0

def run(args):
    message.bright("* Installing wks basics")
    os.system("sudo apt install -qqy cmake ninja-build g++")
    
    for directory in git.get_directories():
        config = env.get_config(directory)

        if config is not None and "requirements" in config:
            message.bright(f"* Executing requirements for {directory}")
            for entry in config["requirements"]:
                os.system(f"cd {directory}; {entry}")



import subprocess
import os
from . import env, git, message, cmake

name = "build"
help = """Runs the build"""
usage = ""
min_args = 0


def run(args):
    result = 1
    message.bright("* Building")

    if not os.path.exists("build"):
        os.makedirs("build")

    if subprocess.getoutput("which ninja") != "":
        cmd = "cd build; cmake -G Ninja ..; ninja %s" % " ".join(args)
        result = os.system(cmd)
    else:
        print(
            message.warn(
                "Ninja was not found, you can consider: apt-get install ninja-build"
            )
        )
        if input("Continue with Makefiles? (y/n) ") == "y":
            cmd = "cd build; cmake ..; make %s" % " ".join(args)
            result = os.system(cmd)

    if result != 0:
        message.bright(
            message.error("\n! Errors while building, read log for more details\n")
        )
        exit(1)
    else:
        message.bright(message.success("\nBuild was successful\n"))



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="wks",
    version="0.4.0",
    author="Rhoban team",
    author_email="team@rhoban.com",
    description="Simple dependencies manager for cmake projects in your workspace",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/rhoban/wks/",
    packages=setuptools.find_packages(),
    keywords="wks workspace deps",
    install_requires=["colorama", "pyyaml", "numpy"],
    include_package_data=True,
    python_requires=">=3.6",
    entry_points={
        "console_scripts": [
            "wks=wks:main.main"
        ]
    },
)



import os
from . import env, git, message, cmake

name = "install"
help = """Installs a module given its name"""
usage = "[repository [repository [...]]]"
min_args = 0


def run(args):
    for repository in args:
        if not git.install(repository, "user"):
            message.error(
                "Not installing " + repository + " because the directory already exists"
            )
    git.scan_all_dependencies()
    cmake.generate()
